mod board;
mod display;
mod logic;
use crossterm::{
    event::{self, KeyCode, KeyEventKind},
    terminal::{disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen},
    ExecutableCommand,
};
use logic::Board;
use ratatui::prelude::{CrosstermBackend, Terminal};
use std::io::{stdout, Result};

/**
* Three Ore Two Wheat
*/

fn main() -> Result<()> {
    stdout().execute(EnterAlternateScreen)?;
    enable_raw_mode()?;
    let mut terminal = Terminal::new(CrosstermBackend::new(stdout()))?;
    terminal.clear()?;

    let board = Box::new(Board::new("example_seed"));
    let hex = display::BoardView::new(board);

    terminal.draw(|frame| {
        frame.render_widget(hex, frame.size());
    })?;

    loop {
        if event::poll(std::time::Duration::from_millis(16))? {
            if let event::Event::Key(key) = event::read()? {
                if key.kind == KeyEventKind::Press && key.code == KeyCode::Char('q') {
                    break;
                }
            }
        }
    }

    stdout().execute(LeaveAlternateScreen)?;
    disable_raw_mode()?;
    Ok(())
}
